@@ -47,7 +47,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
             exit(1)
 
 
-    def install_windows(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL):
+    def install_windows(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL, verbose=False):
         try:
             self.location = location
             if location == ToolchainLocation.LOCAL:
@@ -77,7 +77,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
     # For Mac,we can use Homebrew, but then we can't install multiple versions of toolchain on a single
     # system. For Arduino, we can use the install script and install it in separate directories.
     #
-    def install_mac_with_brew(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL):
+    def install_mac_with_brew(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL, verbose=False):
         try:
             self.location = location
             if location == ToolchainLocation.LOCAL:
@@ -101,20 +101,29 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
             print(f"ERROR: could not install toolchain. {str(e)}")
             exit(1)
 
-    def install_mac(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL):
+    def install_mac(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL, verbose=False):
         try:
             self.location = location
             if location == ToolchainLocation.LOCAL:
                 print(f"Local install {self.name} - {self.desc} for Mac")
 
+                if verbose:
+                    print(f"+ Getting install path for base: {base}")
                 install_exe = self.exec_path(base)
+                if verbose:
+                    print(f"+ Install path: {install_exe}")
                 if self._file_exists(install_exe):
+                    if verbose:
+                        print(f"+ File already exists: {install_exe}")
                     print(f"ERROR: Toolchain app already exists at path: {install_exe}")
                     exit(1)
                 else:
-                    self._exec(f"curl -fsSL https://raw.githubusercontent.com/arduino/arduino-cli/master/install.sh | "
-                               f"BINDIR={base} sh")
-
+                    install_cmd = f"curl -fsSL https://raw.githubusercontent.com/arduino/arduino-cli/master/install.sh | BINDIR={base} sh"
+                    if verbose:
+                        print(f"+ Download and install cmd:\n [ {install_cmd} ] in base: {base}\n\n")
+                    self._exec(install_cmd)
+                    if verbose:
+                        print(f"+ Toolchain downloaded and installed")
             else:
                 print(f"ERROR: non-local toolchains not supported.")
                 exit(1)
@@ -122,7 +131,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
             print(f"ERROR: could not install toolchain. {str(e)}")
             exit(1)
 
-    def uninstall_windows(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL):
+    def uninstall_windows(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL, verbose=False):
         try:
             if location == ToolchainLocation.LOCAL:
                 print(f"Local uninstall {self.name} - {self.desc} for Windows")
@@ -141,7 +150,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
             print(f"ERROR uninstalling tool: {str(e)}")
             exit(1)
 
-    def uninstall_mac_with_brew(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL):
+    def uninstall_mac_with_brew(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL, verbose=False):
         try:
             if location == ToolchainLocation.LOCAL:
                 print(f"Local uninstall {self.name} - {self.desc} for Mac")
@@ -158,13 +167,21 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
             print(f"ERROR uninstalling tool: {str(e)}")
             exit(1)
 
-    def uninstall_mac(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL):
+    def uninstall_mac(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL, verbose=False):
         try:
             if location == ToolchainLocation.LOCAL:
                 print(f"Local uninstall {self.name} - {self.desc} for Mac")
 
                 install_exe = self.exec_path(base)
+                if verbose:
+                    print(f"+ Install executable path: {install_exe}")
+
+                if verbose:
+                    print(f"+ Check that executable exists...")
                 if self._file_exists(install_exe):
+                    if verbose:
+                        print(f"+ Install executable path: {install_exe}")
+
                     import shutil
                     shutil.rmtree(base)
                 else:
@@ -177,7 +194,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
             exit(1)
 
 
-    def reset_windows(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL):
+    def reset_windows(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL, verbose=False):
         try:
             if location == ToolchainLocation.LOCAL:
                 print(f"Local reset to factory settings for {self.name} for Windows")
@@ -209,7 +226,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
             exit(1)
 
 
-    def reset_mac_with_brew(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL):
+    def reset_mac_with_brew(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL, verbose=False):
         try:
             if location == ToolchainLocation.LOCAL:
                 print(f"Local reset to factory-settings for {self.name} for Mac")
@@ -246,32 +263,99 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
             print(f"ERROR: Could not reset {install_exe}: {str(e)}")
             exit(1)
 
-    def reset_mac(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL):
+    def reset_mac(self, base=Toolchain.base(), location=ToolchainLocation.LOCAL, verbose=False):
         try:
             if location == ToolchainLocation.LOCAL:
                 print(f"Local reset to factory-settings for {self.name} for Mac")
 
                 install_path = self.install_path(base)
+                if verbose:
+                    print(f"+ Installer path: {install_path} with base: {base}")
                 install_exe = self.exec_path(install_path)
+                if verbose:
+                    print(f"+ Install executable: {install_exe}")
+                    print(f"+ Check if exists...")
+
                 if install_exe.exists():
+                    if verbose:
+                        print(f"+ Executable exists. Checking toolchain config at: {ARDUINO_TOOLCHAIN_CONFIG}")
+
                     if not self._file_exists(ARDUINO_TOOLCHAIN_CONFIG):
-                        self._exec(f"{install_exe} config init --overwrite")
+                        if verbose:
+                            print(f"+ Arduino Toolchain config exists. Running init to create basic skeleton.")
+
+                        cmd = f"{install_exe} config init --overwrite"
+                        if verbose:
+                            print(f" + Invoking: {cmd}")
+                        self._exec(cmd)
+
+                    if verbose:
+                        print(f" + Invoking: {cmd}")
+                    cmd = f"{install_exe} config set board_manager.additional_urls https://raw.githubusercontent.com/espressif/arduino-esp32/gh-pages/package_esp32_index.json"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} config set library.enable_unsafe_install true"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} core update-index"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} core install esp32:esp32"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} lib install ArduinoJson"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} lib install ArduinoMqttClient"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} lib install FastLED"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} lib install TinyGPSPlus-ESP32"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} lib install --git-url https://github.com/m5stack/M5Core2.git"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENV.git"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENCODER.git"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} lib install --git-url https://github.com/aws-samples/arduino-aws-greengrass-iot.git"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
+
+                    cmd = f"{install_exe} lib install --git-url https://github.com/awslabs/simpleiot-arduino.git"
+                    if verbose:
+                        print(f" + Exec: {cmd}")
+                    self._exec(cmd)
 
-                    self._exec(
-                        f"{install_exe} config set board_manager.additional_urls https://raw.githubusercontent.com/espressif/arduino-esp32/gh-pages/package_esp32_index.json")
-                    self._exec(f"{install_exe} config set library.enable_unsafe_install true")
-                    self._exec(f"{install_exe} core update-index")
-                    self._exec(f"{install_exe} core install esp32:esp32")
-                    self._exec(f"{install_exe} lib install ArduinoJson")
-                    self._exec(f"{install_exe} lib install ArduinoMqttClient")
-                    self._exec(f"{install_exe} lib install FastLED")
-                    self._exec(f"{install_exe} lib install TinyGPSPlus-ESP32")
-                    self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/M5Core2.git")
-                    self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENV.git")
-                    self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENCODER.git")
-                    self._exec(
-                        f"{install_exe} lib install --git-url https://github.com/aws-samples/arduino-aws-greengrass-iot.git")
-                    self._exec(f"{install_exe} lib install --git-url https://github.com/awslabs/simpleiot-arduino.git")
                     print(f"Done: {install_exe} configured")
                 else:
                     print(f"ERROR: build tool not found in local path: {base}.\nPlease uninstall then re-install.")
@@ -287,7 +371,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
     #
     # Parameters will be passed to compiler and flash tool
     #
-    def build(self, base, dirpath, command):
+    def build(self, base, dirpath, command, verbose=False):
         exec = self.exec_path(base)
         full_command = f"{exec} {command}"
         os.chdir(dirpath)
@@ -296,7 +380,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
         self._invoke_unbuffered(full_command)
         return True
 
-    def flash(self, base, dirpath, command):
+    def flash(self, base, dirpath, command, verbose=False):
         exec = self.exec_path(base)
         full_command = f"{exec} {command}"
         print(f"DIR: {dirpath}")
@@ -305,7 +389,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
         self._invoke_unbuffered(full_command)
         return True
 
-    def build_and_flash(self, base, dirpath, command):
+    def build_and_flash(self, base, dirpath, command, verbose=False):
         install_path = self.install_path(base)
         exec = self.exec_path(install_path)
         full_command = f"{exec} {command}"
